==> owncloud-9.0.3.tgz: owncloud/settings/l10n/ug.js <==
OC.L10N.register(
    "settings",
    {
    "Sharing" : "ھەمبەھىر",
    "Log" : "خاتىرە",
    "Language changed" : "تىل ئۆزگەردى",
    "Invalid request" : "ئىناۋەتسىز ئىلتىماس",
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "Admins can't remove themself from the admin group" : "باشقۇرغۇچى ئۆزىنى باشقۇرۇش گۇرۇپپىسىدىن چىقىرىۋېتەلمەيدۇ",
    "Unable to add user to group %s" : "ئىشلەتكۈچىنى %s گۇرۇپپىغا قوشالمايدۇ",
    "Unable to remove user from group %s" : "ئىشلەتكۈچىنى %s گۇرۇپپىدىن چىقىرىۋېتەلمەيدۇ",
    "Couldn't update app." : "ئەپنى يېڭىلىيالمايدۇ.",
    "Email saved" : "تورخەت ساقلاندى",
    "All" : "ھەممىسى",
    "Please wait...." : "سەل كۈتۈڭ…",
    "Disable" : "چەكلە",
    "Enable" : "قوزغات",
    "Updating...." : "يېڭىلاۋاتىدۇ…",
    "Error while updating app" : "ئەپنى يېڭىلاۋاتقاندا خاتالىق كۆرۈلدى",
    "Updated" : "يېڭىلاندى",
    "Delete" : "ئۆچۈر",
    "Groups" : "گۇرۇپپا",
    "undo" : "يېنىۋال",
    "never" : "ھەرگىز",
    "add group" : "گۇرۇپپا قوش",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "__language_name__" : "ئۇيغۇرچە",
    "None" : "يوق",
    "Login" : "تىزىمغا كىرىڭ",
    "Encryption" : "شىفىرلاش",
    "Server address" : "مۇلازىمېتىر ئادرىسى",
    "Port" : "ئېغىز",
    "More" : "تېخىمۇ كۆپ",
    "Less" : "ئاز",
    "Version" : "نەشرى",
    "Forum" : "مۇنبەر",
    "Cancel" : "ۋاز كەچ",
    "Email" : "تورخەت",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Password" : "ئىم",
    "Unable to change your password" : "ئىمنى ئۆزگەرتكىلى بولمايدۇ.",
    "Current password" : "نۆۋەتتىكى ئىم",
    "New password" : "يېڭى ئىم",
    "Change password" : "ئىم ئۆزگەرت",
    "Language" : "تىل",
    "Help translate" : "تەرجىمىگە ياردەم",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Create" : "قۇر",
    "Unlimited" : "چەكسىز",
    "Other" : "باشقا",
    "set new password" : "يېڭى ئىم تەڭشە",
    "Default" : "كۆڭۈلدىكى"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/settings/l10n/ug.js <==
OC.L10N.register(
    "settings",
    {
    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
    "__language_name__" : "ئۇيغۇرچە",
    "Language changed" : "تىل ئۆزگەردى",
    "Invalid request" : "ئىناۋەتسىز ئىلتىماس",
    "Admins can't remove themself from the admin group" : "باشقۇرغۇچى ئۆزىنى باشقۇرۇش گۇرۇپپىسىدىن چىقىرىۋېتەلمەيدۇ",
    "All" : "ھەممىسى",
    "Please wait...." : "سەل كۈتۈڭ…",
    "Disable" : "چەكلە",
    "Enable" : "قوزغات",
    "Updating...." : "يېڭىلاۋاتىدۇ…",
    "Error while updating app" : "ئەپنى يېڭىلاۋاتقاندا خاتالىق كۆرۈلدى",
    "Updated" : "يېڭىلاندى",
    "Delete" : "ئۆچۈر",
    "Groups" : "گۇرۇپپا",
    "undo" : "يېنىۋال",
    "never" : "ھەرگىز",
    "add group" : "گۇرۇپپا قوش",
    "enabled" : "قوزغىتىلغان",
    "disabled" : "چەكلەنگەن",
    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
    "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
    "Forum" : "مۇنبەر",
    "Sharing" : "ھەمبەھىر",
    "Log" : "خاتىرە",
    "None" : "يوق",
    "Login" : "تىزىمغا كىرىڭ",
    "Encryption" : "شىفىرلاش",
    "Server address" : "مۇلازىمېتىر ئادرىسى",
    "Port" : "ئېغىز",
    "Cancel" : "ۋاز كەچ",
    "Email" : "تورخەت",
    "Your email address" : "تورخەت ئادرېسىڭىز",
    "Password" : "ئىم",
    "Unable to change your password" : "ئىمنى ئۆزگەرتكىلى بولمايدۇ.",
    "Current password" : "نۆۋەتتىكى ئىم",
    "New password" : "يېڭى ئىم",
    "Change password" : "ئىم ئۆزگەرت",
    "Language" : "تىل",
    "Help translate" : "تەرجىمىگە ياردەم",
    "Unlimited" : "چەكسىز",
    "Name" : "ئاتى",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Version" : "نەشرى",
    "Personal" : "شەخسىي",
    "Error" : "خاتالىق",
    "Create" : "قۇر",
    "Other" : "باشقا",
    "set new password" : "يېڭى ئىم تەڭشە",
    "Default" : "كۆڭۈلدىكى"
},
"nplurals=1; plural=0;");
